<?php
namespace plugins\file_manager\services;
use plugins\file_manager\library\exceptions;

class UploadFile {

    private $name;
    private $path;

    public function __construct( $name, $path ) {
        $this->name = $name;
        $this->path = $path;
    }

    public function perform( $listener ) {
        if ( !is_writable( $this->path ) ) {
            throw new exceptions\DirectoryNotWritableException( sprintf( 'The directory %s is not writable.', dirname( $this->path ) ) );
        }
        $upload = new \Upload( $this->name );
        
        $fullname = $this->path . DS . $upload->sanitize( $upload->getFileName() );
        if ( file_exists( $fullname ) ) {
            throw new exceptions\FileExistsException( sprintf( 'The file %s already exists.', $fullname ) );
        }
        
        $upload->validate();
        if ( !$upload->move( $this->path . DS ) ) {
            throw new \RuntimeException( sprintf( 'Unable to upload the file %s.', $upload->getFileName() ) );
        }
    }
}
